@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 #include "translatorutil.h"
 #include <KLocalizedString>
-#include <KComboBox>
+#include <QComboBox>
 using namespace PimCommon;
 
 TranslatorUtil::TranslatorUtil()
@@ -221,7 +221,7 @@ void PimCommon::TranslatorUtil::addPairToMap(QMap<QString, QString> &map, const
     map.insert(pair.first, pair.second);
 }
 
-void PimCommon::TranslatorUtil::addItemToFromComboBox(KComboBox *combo, const QPair<QString, QString> &pair)
+void PimCommon::TranslatorUtil::addItemToFromComboBox(QComboBox *combo, const QPair<QString, QString> &pair)
 {
     combo->addItem(pair.first, pair.second);
 }
