@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -23,8 +23,7 @@
 
 #include <QWidget>
 #include "pimcommonakonadi_export.h"
-namespace PimCommon
-{
+namespace PimCommon {
 class ContentTypeWidgetPrivate;
 class PIMCOMMONAKONADI_EXPORT ContentTypeWidget : public QWidget
 {
@@ -33,11 +32,11 @@ public:
     explicit ContentTypeWidget(QWidget *parent = nullptr);
     ~ContentTypeWidget();
 
-    int currentIndex() const;
+    Q_REQUIRED_RESULT int currentIndex() const;
     void setCurrentIndex(int index);
 
     void setCurrentItem(const QString &name);
-    QString currentText() const;
+    Q_REQUIRED_RESULT QString currentText() const;
 
 Q_SIGNALS:
     void activated(int index);
